@@ -4,7 +4,7 @@ use utf8;
 
 package Pod::Weaver::PluginBundle::Author::LESPEA;
 BEGIN {
-  $Pod::Weaver::PluginBundle::Author::LESPEA::VERSION = '1.000000';
+  $Pod::Weaver::PluginBundle::Author::LESPEA::VERSION = '1.001000';
 }
 BEGIN {
   $Pod::Weaver::PluginBundle::Author::LESPEA::AUTHORITY = 'cpan:LESPEA';
@@ -18,56 +18,56 @@ use Pod::Weaver::Config::Assembler;
 
 
 sub _exp {
-    return Pod::Weaver::Config::Assembler->expand_package( $_[0] );
+    return Pod::Weaver::Config::Assembler->expand_package($_[0]);
 }
 
 
 sub mvp_bundle_config {
-    my ( undef, $params ) = @_;
+    my (undef, $params) = @_;
     my $opts = $params->{payload};
 
     ## no critic 'ValuesAndExpressions::RequireInterpolationOfMetachars'
     my @setup = (
-        [ '@Author::LESPEA/CorePrep', _exp('@CorePrep'), {} ],
+        [ '@Author::LESPEA/CorePrep'             , _exp('@CorePrep')             , {} ]                            ,
 
-        [ '@Author::LESPEA/Name',    _exp('Name'),    {} ],
-        [ '@Author::LESPEA/Version', _exp('Version'), {} ],
+        [ '@Author::LESPEA/Name'                 , _exp('Name')                  , {} ]                            ,
+        [ '@Author::LESPEA/Version'              , _exp('Version')               , {} ]                            ,
 
-        [ '@Author::LESPEA/prelude', _exp('Region'), { region_name => 'prelude' } ],
+        [ '@Author::LESPEA/prelude'              , _exp('Region')                , { region_name => 'prelude' } ]  ,
 
-        [ 'SYNOPSIS',    _exp('Generic'), {} ],
-        [ 'OVERVIEW',    _exp('Generic'), {} ],
-        [ 'DESCRIPTION', _exp('Generic'), {} ],
+        [ 'SYNOPSIS'                             , _exp('Generic')               , {} ]                            ,
+        [ 'OVERVIEW'                             , _exp('Generic')               , {} ]                            ,
+        [ 'DESCRIPTION'                          , _exp('Generic')               , {} ]                            ,
 
-        [ 'EXPORTS', _exp('Generic'), {} ],
+        [ 'EXPORTS'                              , _exp('Generic')               , {} ]                            ,
 
-        [ 'OPTIONS',    _exp('Collect'), { command => 'option' } ],
-        [ 'ATTRIBUTES', _exp('Collect'), { command => 'attr' } ],
-        [ 'METHODS',    _exp('Collect'), { command => 'method' } ],
-        [ 'FUNCTIONS',  _exp('Collect'), { command => 'func' } ],
+        [ 'OPTIONS'                              , _exp('Collect')               , { command => 'option' } ]       ,
+        [ 'ATTRIBUTES'                           , _exp('Collect')               , { command => 'attr' } ]         ,
+        [ 'METHODS'                              , _exp('Collect')               , { command => 'method' } ]       ,
+        [ 'FUNCTIONS'                            , _exp('Collect')               , { command => 'func' } ]         ,
 
-        [ '@Author::LESPEA/Leftovers', _exp('Leftovers'), {} ],
-        [ '@Author::LESPEA/postlude',     _exp('Region'),       { region_name => 'postlude' } ],
-        [ '@Author::LESPEA/SeeAlso',      _exp('SeeAlso'),      {} ],
-        [ '@Author::LESPEA/Installation', _exp('Installation'), {} ],
-        [ '@Author::LESPEA/Authors',      _exp('Authors'),      {} ],
+        [ '@Author::LESPEA/Leftovers'            , _exp('Leftovers')             , {} ]                            ,
+        [ '@Author::LESPEA/postlude'             , _exp('Region')                , { region_name => 'postlude' } ] ,
+        [ '@Author::LESPEA/SeeAlso'              , _exp('SeeAlso')               , {} ]                            ,
+        [ '@Author::LESPEA/Installation'         , _exp('Installation')          , {} ]                            ,
+        [ '@Author::LESPEA/Authors'              , _exp('Authors')               , {} ]                            ,
     );
 
 
     #  Don't include "support" if this isn't a cpan module
-    if ( $opts->{is_cpan} ) {
+    if ($opts->{is_cpan}) {
         push @setup, [ '@Author::LESPEA/Support', _exp('Support'), {} ];
     }
 
 
-    push @setup,
-      ( [ '@Author::LESPEA/Legal',              _exp('Legal'),              {} ],
-        [ '@Author::LESPEA/WarrantyDisclaimer', _exp('WarrantyDisclaimer'), {} ],
-        [ '@Author::LESPEA/-Transformer', _exp('-Transformer'), { transformer => 'List' } ],
-      );
+    push @setup, (
+        [ '@Author::LESPEA/Legal'              , _exp('Legal')              , {} ]                        ,
+        [ '@Author::LESPEA/WarrantyDisclaimer' , _exp('WarrantyDisclaimer') , {} ]                        ,
+        [ '@Author::LESPEA/-Transformer'       , _exp('-Transformer')       , { transformer => 'List' } ] ,
+    );
 
     return @setup;
-} ## end sub mvp_bundle_config
+}
 
 
 # Happy ending
@@ -82,7 +82,7 @@ Pod::Weaver::PluginBundle::Author::LESPEA - A bundle that implements LESPEA's pr
 
 =head1 VERSION
 
-version 1.000000
+version 1.001000
 
 =head1 SYNOPSIS
 
